# Tic-Tac-Toe

## Description

**tic_tac_toe** is a Python package for 2 players to play the game of tic-tac-toe distributed under the MIT license.

## Dependencies

tic_tac_toe requires:

- Python (>= 3.6)

## Installation

Using ``pip``   ::

    pip install tic-tac-toe-jf

## File Descriptions

- tic_tac_toe.py (Python file in which the TicTacToe class is defined)

## How to use the package

```text
game = TicTacToe()  # Create an instance of the TicTacToe class

game.play_game()  # Call the play_game() member function to start playing the game
```

## Source code

You can check the latest sources with the command::

    git clone https://github.com/joshua-furtado/tic_tac_toe.git

## Authors

**Joshua Furtado**


